@@ -1,34 +1,37 @@
 """Models for the `multilingual_tags` app."""
 from django.contrib.contenttypes import generic, models as ctype_models
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ugettext_lazy as _, get_language
 
 from hvad.models import TranslatableModel, TranslatedFields, TranslationManager
 
 
 class TagManager(TranslationManager):
     """Manager for the `Tag` model."""
+    def get_for_model(self, obj):
+        """Returns the tags for a specific model/content type."""
+        qs = Tag.objects.language(get_language())
+        qs = qs.filter(
+            tagged_items__content_type=ctype_models.ContentType.objects.get_for_model(obj))  # NOQA
+        return qs
 
     def get_for_obj(self, obj):
         """Returns the tags for a specific object."""
-        qs = self.get_queryset()
-        qs = qs.filter(tagged_items__object_id=obj.id,
-                       tagged_items__content_type=
-                       ctype_models.ContentType.objects.get_for_model(
-                           obj.__class__))
+        qs = Tag.objects.language(get_language())
+        qs = qs.filter(
+            tagged_items__object_id=obj.id,
+            tagged_items__content_type=ctype_models.ContentType.objects.get_for_model(obj))  # NOQA
         return qs
 
     def get_for_queryset(self, obj_queryset):
         """Returns all tags for a whole queryset of objects."""
-        qs = self.get_queryset()
+        qs = Tag.objects.language(get_language())
         if obj_queryset.count() == 0:
             return qs.none()
         qs = qs.filter(
             tagged_items__object_id__in=[
                 obj.id for obj in obj_queryset],
-            tagged_items__content_type=
-            ctype_models.ContentType.objects.get_for_model(
-                obj_queryset[0].__class__))
+            tagged_items__content_type=ctype_models.ContentType.objects.get_for_model(obj_queryset[0]))  # NOQA
         return qs.distinct()
 
 
@@ -85,7 +88,7 @@ class TaggedItem(models.Model):
     object = generic.GenericForeignKey('content_type', 'object_id')
 
     def __unicode__(self):
-        return '{0}: #{1}'.format(self.object, self.tag)
+        return u'{0}: #{1}'.format(self.object, self.tag)
 
     class Meta:
         unique_together = ('content_type', 'object_id', 'tag')
